==> vokoscreen-ng_3.0.7.orig.tar.gz: vokoscreenNG-3.0.7/src/language/no.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="no" version="2.1">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Velg én til flere enheter</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Bytt til vindu</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Bytt til fullskjerm</translation>
    </message>
</context>
<context>
    <name>QvkCountdown</name>
    <message>
        <source>Countdown</source>
        <translation>Nedtelling</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Velg én til flere enheter</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Advarsel</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Opptaket har ikke startet, for lite ledig diskplass.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Ledig diskplass grense nådd.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Grense for ledig diskplass.</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Opptaket ble stoppet, for lite ledig diskplass.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Fullskjerm</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Vindu</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Ingen filutforsker funnet.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Vennligst installere en filutforsker.</translation>
    </message>
    <message>
        <source>Desktop session is a Wayland session</source>
        <translation>Skrivebordsøkt er en Wayland økt.</translation>
    </message>
    <message>
        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
        <translation>Wayland er ikke supportert. Et skjermopptak viser en svart skjerm. Vennligst logg ut og start en X11 Desktop økt.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Kildekode</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Hjemmeside</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Oversettelser</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donere</translation>
    </message>
    <message>
        <source>Wayland desktop session detected</source>
        <translation>Wayland skrivebordsøkt oppdaget</translation>
    </message>
</context>
<context>
    <name>QvkPlayer</name>
    <message>
        <source>Open File</source>
        <translation>Åpne Fil</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Område</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppe</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Forsett</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Avslutt</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppe</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Forsett</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Avslutt</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Snu horisontalt</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Snu vertikalt</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertere</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grå</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Svart-hvit</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Fjern vindusramme</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Kamera instillinger</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Område</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Nullstille</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Forstørrelse</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Nedtelling</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Videostørrelse:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Ledig diskplass:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informasjon</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Opptakstid:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Lyd</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Rammer</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videokodek</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Lydkodek</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvalitet</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>ikke ta opp muse courser</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Time</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minutt</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Start timeren</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Stopp opptak etter</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Timer</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minutter</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekunder</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Video sti</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Grense for ledig diskplass.</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Vis i systemstatusfeltet</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Sekund venting før opptak</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Se etter oppdateringer</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Tilgjengelig</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Ikke tilgjengelig</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppe</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Forsett</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Spille</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Mappe</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertere</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grå</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Send Rapport</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Spill av siste opptak</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Åpne mappe</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimert når opptak starter</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Starter minimert</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Snu horisontalt</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Snu vertikalt</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Svart-hvit</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Fjern vindusramme</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donasjon</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Nullstille alle innstillinger ved neste oppstart.</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Opphavsrett og lisens fra bilder</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Skjermopptak</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Spiller</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Logg</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Opphavsrett og lisens fra bilder</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Spille</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppe</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Åpne Fil</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>fullskjerm</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Forrige bilde</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Neste bilde</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Stilne</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Flytt meny</translation>
    </message>
</context>
</TS>

==> vokoscreen-ng_3.1.0.orig.tar.gz: vokoscreenNG-3.1.0/src/language/no.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="no">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Velg én til flere enheter</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Bytt til vindu</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Bytt til fullskjerm</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Velg én til flere enheter</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Ingen filutforsker funnet.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Vennligst installere en filutforsker.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Advarsel</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Opptaket har ikke startet, for lite ledig diskplass.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Ledig diskplass grense nådd.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Grense for ledig diskplass.</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Opptaket ble stoppet, for lite ledig diskplass.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Fullskjerm</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Vindu</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Ingen filutforsker funnet.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Vennligst installere en filutforsker.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Kildekode</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Hjemmeside</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Oversettelser</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donere</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Velg én til flere enheter</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Område</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppe</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Forsett</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Avslutt</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Forstørrelse</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppe</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Forsett</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Avslutt</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Snu horisontalt</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Snu vertikalt</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertere</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grå</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Svart-hvit</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Fjern vindusramme</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Kamera instillinger</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Område</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Nullstille</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Forstørrelse</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Nedtelling</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Videostørrelse:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Ledig diskplass:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informasjon</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Opptakstid:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Lyd</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Rammer</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videokodek</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Lydkodek</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvalitet</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>ikke ta opp muse courser</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Time</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minutt</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Start timeren</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Stopp opptak etter</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Timer</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minutter</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekunder</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Video sti</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Grense for ledig diskplass.</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Vis i systemstatusfeltet</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Sekund venting før opptak</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Se etter oppdateringer</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Tilgjengelig</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Ikke tilgjengelig</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppe</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Forsett</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Spille</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Mappe</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertere</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grå</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Send Rapport</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Spill av siste opptak</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Åpne mappe</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimert når opptak starter</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Starter minimert</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Snu horisontalt</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Snu vertikalt</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Svart-hvit</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Fjern vindusramme</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donasjon</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Nullstille alle innstillinger ved neste oppstart.</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Opphavsrett og lisens fra bilder</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Skjermopptak</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Spiller</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Logg</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Opphavsrett og lisens fra bilder</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Spille</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppe</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Åpne Fil</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>fullskjerm</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Forrige bilde</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Neste bilde</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Stilne</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Flytt meny</translation>
    </message>
</context>
</TS>
